@@ -1,7 +1,7 @@
 import re
 
 _hours_minutes_seconds_re = re.compile(r"""
-    ^-?(?P<hours>\d+):(?P<minutes>\d+):(?P<seconds>\d+)$
+    ^-?(?:(?P<hours>\d+):)?(?P<minutes>\d+):(?P<seconds>\d+)$
 """, re.VERBOSE)
 
 _hours_minutes_seconds_2_re = re.compile(r"""^-?
@@ -21,6 +21,7 @@ def hours_minutes_seconds(value):
     """converts a timestamp to seconds
 
       - hours:minutes:seconds to seconds
+      - minutes:seconds to seconds
       - 11h22m33s to seconds
       - 11h to seconds
       - 20h15m to seconds
@@ -47,6 +48,13 @@ def hours_minutes_seconds(value):
     return s
 
 
+def seconds_to_hhmmss(seconds):
+    hours, seconds = divmod(seconds, 3600)
+    minutes, seconds = divmod(seconds, 60)
+    return "{0:02d}:{1:02d}:{2}".format(int(hours), int(minutes), "{0:02.1f}".format(seconds) if seconds % 1 else "{0:02d}".format(int(seconds)))
+
+
 __all__ = [
     "hours_minutes_seconds",
+    "seconds_to_hhmmss"
 ]
